backBufferDurationMs property

int? backBufferDurationMs
final

The duration, in milliseconds, of media to retain in the buffer prior to the current playback position.

Ignored on platforms that do not support controlling the back buffer.

Implementation

final int? backBufferDurationMs;